==> senior_platform_authentication_ui-0.0.1.tar.gz: lib/src/presentation/username_authentication/widgets/username_authentication_form.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_platform_authentication/senior_platform_authentication.dart';

import '../../../core/l10n/l10n_extension.dart';
import '../../../core/utils/constants.dart';
import '../../../core/utils/validators.dart';
import '../../password_recovery/password_recovery_modal.dart';
import '../cubit/username_authentication_cubit.dart';

class UserNameAuthenticationForm extends StatefulWidget {
  const UserNameAuthenticationForm({
    super.key,
  });

  @override
  State<UserNameAuthenticationForm> createState() =>
      _UserNameAuthenticationFormState();
}

class _UserNameAuthenticationFormState
    extends State<UserNameAuthenticationForm> {
  final _formKey = GlobalKey<FormState>();

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<UserNameAuthenticationCubit,
        UserNameAuthenticationState>(
      builder: (context, state) {
        return Form(
          key: _formKey,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              SeniorText.h3(context.l10n.userNameScreenSubTitle),
              const SizedBox(height: SeniorSpacing.xmedium),
              const _UserNameTextField(),
              const SizedBox(height: SeniorSpacing.normal),
              (state.authenticationFlow == AuthenticationFlow.password ||
                      state.authenticationFlow == AuthenticationFlow.mfa)
                  ? const _PasswordTextField()
                  : const SizedBox.shrink(),
              const Spacer(),
              Builder(
                builder: (context) {
                  final isLogin = (state.authenticationFlow ==
                          AuthenticationFlow.password ||
                      state.authenticationFlow == AuthenticationFlow.mfa);

                  return Column(
                    crossAxisAlignment: CrossAxisAlignment.stretch,
                    children: [
                      SeniorButton(
                        label: isLogin
                            ? context.l10n.login_btn_text
                            : context.l10n.next_btn_text,
                        busy: state.status == NetworkStatus.loading,
                        disabled: state.status == NetworkStatus.loading,
                        size: SeniorButtonSize.big,
                        onPressed: () {
                          if (!_formKey.currentState!.validate()) {
                            return;
                          }

                          if (isLogin) {
                            context.read<UserNameAuthenticationCubit>().login();
                          } else {
                            context
                                .read<UserNameAuthenticationCubit>()
                                .getTenantLoginSettings();
                          }
                        },
                      ),
                      isLogin
                          ? const SizedBox(height: SeniorSpacing.normal)
                          : const SizedBox.shrink(),
                      isLogin
                          ? _PasswordRecoveryButton(
                              changePasswordSettings: state
                                  .tenantLoginSettings!.changePasswordSettings,
                              username: state.username,
                            )
                          : const SizedBox.shrink(),
                    ],
                  );
                },
              ),
            ],
          ),
        );
      },
    );
  }
}

class _UserNameTextField extends StatelessWidget {
  const _UserNameTextField();

  @override
  Widget build(BuildContext context) {
    return SeniorTextField(
      style: const SeniorTextFieldStyle(
        iconColor: SeniorColors.secondaryColor700,
      ),
      leftIcon: FontAwesomeIcons.solidUser,
      label: context.l10n.username_hint,
      onChanged: (String text) {
        context.read<UserNameAuthenticationCubit>().onUserNameChanged(text);
      },
      validateOnChange: false,
      validator: (value) => validateUserName(context, value),
    );
  }
}

class _PasswordTextField extends StatelessWidget {
  const _PasswordTextField();

  @override
  Widget build(BuildContext context) {
    return SeniorTextField.password(
      style: const SeniorTextFieldStyle(
        iconColor: SeniorColors.secondaryColor700,
      ),
      label: context.l10n.password_hint,
      leftIcon: FontAwesomeIcons.lock,
      onChanged: (String text) {
        context.read<UserNameAuthenticationCubit>().onPasswordChanged(text);
      },
      validateOnChange: false,
      validator: (value) => validatePassword(context, value),
    );
  }
}

class _PasswordRecoveryButton extends StatelessWidget {
  final ChangePasswordSettings changePasswordSettings;
  final String username;

  const _PasswordRecoveryButton({
    required this.changePasswordSettings,
    required this.username,
  });

  @override
  Widget build(BuildContext context) {
    return SeniorButton(
      label: context.l10n.recovery_password_btn_text,
      size: SeniorButtonSize.big,
      type: SeniorButtonType.ghost,
      onPressed: () {
        SeniorBottomSheet.showBottomSheet(
          enableDrag: true,
          isDismissible: true,
          context: context,
          hasCloseButton: true,
          onTapCloseButton: () {
            Navigator.pop(context);
          },
          content: <Widget>[
            PasswordRecoveryModal(
              changePasswordSettings: changePasswordSettings,
              username: username,
            ),
          ],
        );
      },
    );
  }
}

==> senior_platform_authentication_ui-0.0.2.tar.gz: lib/src/presentation/username_authentication/widgets/username_authentication_form.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_platform_authentication/senior_platform_authentication.dart';

import '../../../core/l10n/l10n_extension.dart';
import '../../../core/utils/constants.dart';
import '../../../core/utils/validators.dart';
import '../../password_recovery/password_recovery_modal.dart';
import '../cubit/username_authentication_cubit.dart';

class UserNameAuthenticationForm extends StatefulWidget {
  const UserNameAuthenticationForm({
    super.key,
  });

  @override
  State<UserNameAuthenticationForm> createState() =>
      _UserNameAuthenticationFormState();
}

class _UserNameAuthenticationFormState
    extends State<UserNameAuthenticationForm> {
  final _formKey = GlobalKey<FormState>();

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<UserNameAuthenticationCubit,
        UserNameAuthenticationState>(
      builder: (context, state) {
        return Form(
          key: _formKey,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              SeniorText.h3(
                context.l10n.userNameScreenSubTitle,
                emphasis: true,
              ),
              const SizedBox(height: SeniorSpacing.xmedium),
              const _UserNameTextField(),
              const SizedBox(height: SeniorSpacing.normal),
              (state.authenticationFlow == AuthenticationFlow.password ||
                      state.authenticationFlow == AuthenticationFlow.mfa)
                  ? const _PasswordTextField()
                  : const SizedBox.shrink(),
              const Spacer(),
              Builder(
                builder: (context) {
                  final isLogin = (state.authenticationFlow ==
                          AuthenticationFlow.password ||
                      state.authenticationFlow == AuthenticationFlow.mfa);

                  return Column(
                    crossAxisAlignment: CrossAxisAlignment.stretch,
                    children: [
                      SeniorButton(
                        label: isLogin
                            ? context.l10n.login_btn_text
                            : context.l10n.next_btn_text,
                        busy: state.status == NetworkStatus.loading,
                        disabled: state.status == NetworkStatus.loading ||
                            (isLogin
                                ? (state.username.isEmpty ||
                                    state.password.isEmpty)
                                : state.username.isEmpty),
                        size: SeniorButtonSize.big,
                        onPressed: () {
                          if (!_formKey.currentState!.validate()) {
                            return;
                          }

                          if (isLogin) {
                            context.read<UserNameAuthenticationCubit>().login();
                          } else {
                            context
                                .read<UserNameAuthenticationCubit>()
                                .getTenantLoginSettings();
                          }
                        },
                      ),
                      isLogin
                          ? const SizedBox(height: SeniorSpacing.normal)
                          : const SizedBox.shrink(),
                      isLogin
                          ? _PasswordRecoveryButton(
                              changePasswordSettings: state
                                  .tenantLoginSettings!.changePasswordSettings,
                              username: state.username,
                            )
                          : const SizedBox.shrink(),
                    ],
                  );
                },
              ),
            ],
          ),
        );
      },
    );
  }
}

class _UserNameTextField extends StatelessWidget {
  const _UserNameTextField();

  @override
  Widget build(BuildContext context) {
    return SeniorTextField(
      keyboardType: TextInputType.emailAddress,
      textInputAction: TextInputAction.done,
      validateOnChange: false,
      autocorrect: false,
      leftIcon: FontAwesomeIcons.solidUser,
      label: context.l10n.username_hint,
      hintText: context.l10n.username_textfield_hint_text,
      validator: (value) => validateUserName(context, value),
      onChanged: (String text) {
        context.read<UserNameAuthenticationCubit>().onUserNameChanged(text);
      },
    );
  }
}

class _PasswordTextField extends StatelessWidget {
  const _PasswordTextField();

  @override
  Widget build(BuildContext context) {
    return SeniorTextField.password(
      label: context.l10n.password_hint,
      leftIcon: FontAwesomeIcons.lock,
      onChanged: (String text) {
        context.read<UserNameAuthenticationCubit>().onPasswordChanged(text);
      },
      validateOnChange: false,
      textInputAction: TextInputAction.done,
      validator: (value) => validatePassword(context, value),
    );
  }
}

class _PasswordRecoveryButton extends StatelessWidget {
  final ChangePasswordSettings changePasswordSettings;
  final String username;

  const _PasswordRecoveryButton({
    required this.changePasswordSettings,
    required this.username,
  });

  @override
  Widget build(BuildContext context) {
    return SeniorButton(
      label: context.l10n.recovery_password_btn_text,
      size: SeniorButtonSize.big,
      type: SeniorButtonType.ghost,
      onPressed: () {
        SeniorBottomSheet.showDynamicBottomSheet(
          enableDrag: true,
          isDismissible: true,
          context: context,
          hasCloseButton: true,
          onTapCloseButton: () {
            Navigator.pop(context);
          },
          content: <Widget>[
            PasswordRecoveryModal(
              changePasswordSettings: changePasswordSettings,
              username: username,
            ),
          ],
        );
      },
    );
  }
}
